@@ -20,7 +20,7 @@ limitations under the License.
 
 from __future__ import print_function
 
-__version__ = '20.6.1'
+__version__ = '20.7.1'
 
 import json
 import os
@@ -243,6 +243,13 @@ class UiAutomatorHelper:
             """
             return self.uiAutomatorHelper.api_instance.device_display_real_size_get()
 
+        def wait_for_new_toast(self, timeout=10000):
+            """
+            :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
+            :return: the text in the Toast if found
+            """
+            return self.uiAutomatorHelper.api_instance.device_wait_for_new_toast_get(timeout=timeout)
+
     def getDisplayRealSize(self):
         """
         :deprecated: use uiAutomatorHelper.device.display_real_size()
@@ -501,7 +508,7 @@ class UiAutomatorHelper:
             :param oid: the oid
             :return: the text
             """
-            return self.uiAutomatorHelper.api_instance.ui_object2_get_text_get(oid=oid)
+            return self.uiAutomatorHelper.api_instance.ui_object2_oid_get_text_get(oid=oid)
 
         def long_click(self, oid):
             """
@@ -520,7 +527,7 @@ class UiAutomatorHelper:
             :param text: the text
             :return: the result of the operation
             """
-            return self.uiAutomatorHelper.api_instance.ui_object2_set_text_post(oid=oid, body=Text(text))
+            return self.uiAutomatorHelper.api_instance.ui_object2_oid_set_text_post(oid=oid, body=Text(text))
 
     #
     # Until
